==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/loader/impl/BooleanSerializerSetImpl.java <==
package io.ciera.tool.sql.loader.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.loader.AttributeSerializerSet;
import io.ciera.tool.sql.loader.BooleanSerializer;
import io.ciera.tool.sql.loader.BooleanSerializerSet;
import io.ciera.tool.sql.loader.impl.AttributeSerializerSetImpl;

import java.util.Arrays;
import java.util.List;


public class BooleanSerializerSetImpl extends InstanceSet<BooleanSerializerSet,BooleanSerializer> implements BooleanSerializerSet {

    // attributes
    @Override
    public void setLoader_name( String ref_loader_name ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setLoader_name( ref_loader_name );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setClass_name( ref_class_name );
    }
    @Override
    public void setValue( String m_value ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setValue( m_value );
    }
    @Override
    public void setLoader_package( String ref_loader_package ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setLoader_package( ref_loader_package );
    }
    @Override
    public void setAttr_name( String ref_attr_name ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setAttr_name( ref_attr_name );
    }


    // selections
    @Override
    public AttributeSerializerSet R3004_is_a_AttributeSerializer() throws XtumlException {
        AttributeSerializerSet attributeserializerset = new AttributeSerializerSetImpl();
        for ( BooleanSerializer booleanserializer : this ) attributeserializerset.add( booleanserializer.R3004_is_a_AttributeSerializer() );
        return attributeserializerset;
    }


    @Override
    public BooleanSerializer nullElement() {
        return BooleanSerializerImpl.EMPTY_BOOLEANSERIALIZER;
    }

    @Override
    public BooleanSerializerSet emptySet() {
      return new BooleanSerializerSetImpl();
    }

    @Override
    public BooleanSerializerSet value() {
        return this;
    }

    @Override
    public List<BooleanSerializer> elements() {
        return Arrays.asList(toArray(new BooleanSerializer[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/loader/impl/BooleanSerializerSetImpl.java <==
package io.ciera.tool.sql.loader.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.loader.AttributeSerializerSet;
import io.ciera.tool.sql.loader.BooleanSerializer;
import io.ciera.tool.sql.loader.BooleanSerializerSet;
import io.ciera.tool.sql.loader.impl.AttributeSerializerSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BooleanSerializerSetImpl extends InstanceSet<BooleanSerializerSet,BooleanSerializer> implements BooleanSerializerSet {

    public BooleanSerializerSetImpl() {
    }

    public BooleanSerializerSetImpl(Comparator<? super BooleanSerializer> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setLoader_name( String ref_loader_name ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setLoader_name( ref_loader_name );
    }
    @Override
    public void setLoader_package( String ref_loader_package ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setLoader_package( ref_loader_package );
    }
    @Override
    public void setAttr_name( String ref_attr_name ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setAttr_name( ref_attr_name );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setClass_name( ref_class_name );
    }
    @Override
    public void setValue( String m_value ) throws XtumlException {
        for ( BooleanSerializer booleanserializer : this ) booleanserializer.setValue( m_value );
    }


    // selections
    @Override
    public AttributeSerializerSet R3004_is_a_AttributeSerializer() throws XtumlException {
        AttributeSerializerSet attributeserializerset = new AttributeSerializerSetImpl();
        for ( BooleanSerializer booleanserializer : this ) attributeserializerset.add( booleanserializer.R3004_is_a_AttributeSerializer() );
        return attributeserializerset;
    }


    @Override
    public BooleanSerializer nullElement() {
        return BooleanSerializerImpl.EMPTY_BOOLEANSERIALIZER;
    }

    @Override
    public BooleanSerializerSet emptySet() {
      return new BooleanSerializerSetImpl();
    }

    @Override
    public BooleanSerializerSet emptySet(Comparator<? super BooleanSerializer> comp) {
      return new BooleanSerializerSetImpl(comp);
    }

    @Override
    public BooleanSerializerSet value() {
        return this;
    }

    @Override
    public List<BooleanSerializer> elements() {
        return Arrays.asList(toArray(new BooleanSerializer[0]));
    }

}
